parserFwk.pyparsing.ParseBaseException

Package parserFwk :: Module pyparsing :: Class ParseBaseException |
[frames | no frames]

## Class ParseBaseException

    Exception --+
                |
               ParseBaseException

Known Subclasses:
  `ParseException`, `ParseFatalException`

base exception class for all parsing runtime exceptions

Method Summary
| `__init__(self, pstr, loc, msg, elem)`
| ``__getattr__`(self, aname)` supported attributes by name are:
| `__repr__(self)`
| `__str__(self)`
| ``markInputline`(self, markerString)` Extracts the exception line from the input string, and marks the location of the exception with a special symbol.
Inherited from `Exception`: `__getitem__`

Class Variable Summary
`tuple` | `__slots__` = `('loc', 'msg', 'pstr', 'parserElement')`

Method Details

### __getattr__(self, aname) (Qualification operator) supported attributes by name are: lineno - returns the line number of the exception text col - returns the column number of the exception text line - returns the line containing the exception text

### markInputline(self, markerString='>!<') Extracts the exception line from the input string, and marks the location of the exception with a special symbol.

Class Variable Details

    ### __slots__ Type: `tuple` Value:
        ('loc', 'msg', 'pstr', 'parserElement')

Generated by Epydoc 2.1 on Wed Apr 11 17:02:38 2007 | http://epydoc.sf.net